@@ -132,7 +132,6 @@ class Create(base.Command):
   _support_max_run_duration = False
   _support_enable_target_shape = True
   _support_confidential_compute_type = False
-  _support_provisioned_throughput = False
   _support_no_address_in_networking = False
   _support_max_count_per_zone = False
   _support_local_ssd_recovery_timeout = False
@@ -158,7 +157,6 @@ class Create(base.Command):
         support_max_run_duration=cls._support_max_run_duration,
         support_enable_target_shape=cls._support_enable_target_shape,
         support_confidential_compute_type=cls._support_confidential_compute_type,
-        support_provisioned_throughput=cls._support_provisioned_throughput,
         support_no_address_in_networking=cls._support_no_address_in_networking,
         support_max_count_per_zone=cls._support_max_count_per_zone,
         support_network_queue_count=cls._support_network_queue_count,
@@ -203,7 +201,6 @@ class Create(base.Command):
         self._support_local_ssd_recovery_timeout,
         self._support_enable_target_shape,
         self._support_confidential_compute_type,
-        self._support_provisioned_throughput,
         self._support_max_count_per_zone,
         self._support_performance_monitoring_unit,
     )
@@ -337,7 +334,6 @@ class CreateBeta(Create):
   _support_visible_core_count = True
   _support_max_run_duration = True
   _support_enable_target_shape = True
-  _support_provisioned_throughput = False
   _support_no_address_in_networking = False
   _support_max_count_per_zone = True
   _support_local_ssd_recovery_timeout = False
@@ -361,7 +357,6 @@ class CreateBeta(Create):
         support_visible_core_count=cls._support_visible_core_count,
         support_max_run_duration=cls._support_max_run_duration,
         support_enable_target_shape=cls._support_enable_target_shape,
-        support_provisioned_throughput=cls._support_provisioned_throughput,
         support_no_address_in_networking=cls._support_no_address_in_networking,
         support_max_count_per_zone=cls._support_max_count_per_zone,
         support_network_queue_count=cls._support_network_queue_count,
@@ -387,7 +382,6 @@ class CreateAlpha(Create):
   _support_max_run_duration = True
   _support_enable_target_shape = True
   _support_confidential_compute_type = True
-  _support_provisioned_throughput = True
   _support_no_address_in_networking = True
   _support_max_count_per_zone = True
   _support_local_ssd_recovery_timeout = True
@@ -411,7 +405,6 @@ class CreateAlpha(Create):
         support_max_run_duration=cls._support_max_run_duration,
         support_enable_target_shape=cls._support_enable_target_shape,
         support_confidential_compute_type=cls._support_confidential_compute_type,
-        support_provisioned_throughput=cls._support_provisioned_throughput,
         support_no_address_in_networking=cls._support_no_address_in_networking,
         support_max_count_per_zone=cls._support_max_count_per_zone,
         support_network_queue_count=cls._support_network_queue_count,
