@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,10 +12,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Command for adding an interface to a Google Compute Engine router."""
+"""Command for adding an interface to a Compute Engine router."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import encoding
 
 from googlecloudsdk.api_lib.compute import base_classes
@@ -24,40 +26,52 @@ from googlecloudsdk.calliope import parser_errors
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 from googlecloudsdk.command_lib.compute.interconnects.attachments import (
     flags as attachment_flags)
+from googlecloudsdk.command_lib.compute.networks.subnets import flags as subnet_flags
 from googlecloudsdk.command_lib.compute.routers import flags as router_flags
 from googlecloudsdk.command_lib.compute.vpn_tunnels import (flags as
                                                             vpn_tunnel_flags)
 
 
 class AddInterface(base.UpdateCommand):
-  """Add an interface to a Google Compute Engine router.
+  """Add an interface to a Compute Engine router.
 
-  *{command}* is used to add an interface to a Google Compute Engine
+  *{command}* is used to add an interface to a Compute Engine
   router.
   """
 
   ROUTER_ARG = None
   VPN_TUNNEL_ARG = None
   INTERCONNECT_ATTACHMENT_ARG = None
+  SUBNETWORK_ARG = None
 
   @classmethod
-  def Args(cls, parser):
+  def _Args(cls, parser):
     cls.ROUTER_ARG = router_flags.RouterArgument()
     cls.ROUTER_ARG.AddArgument(parser, operation_type='update')
 
-    link_parser = parser.add_mutually_exclusive_group(
-        required=True)
+    link_parser = parser.add_mutually_exclusive_group(required=True)
 
+    vpn_tunnel_group = link_parser.add_argument_group('VPN Tunnel')
     cls.VPN_TUNNEL_ARG = vpn_tunnel_flags.VpnTunnelArgumentForRouter(
         required=False)
-    cls.VPN_TUNNEL_ARG.AddArgument(link_parser)
+    cls.VPN_TUNNEL_ARG.AddArgument(vpn_tunnel_group)
 
+    interconnect_attachment_group = link_parser.add_argument_group(
+        'Interconnect Attachment')
     cls.INTERCONNECT_ATTACHMENT_ARG = (
         attachment_flags.InterconnectAttachmentArgumentForRouter())
-    cls.INTERCONNECT_ATTACHMENT_ARG.AddArgument(link_parser)
+    cls.INTERCONNECT_ATTACHMENT_ARG.AddArgument(interconnect_attachment_group)
+
+    subnetwork_group = link_parser.add_argument_group('Subnetwork')
+    cls.SUBNETWORK_ARG = (subnet_flags.SubnetworkArgumentForRouter())
+    cls.SUBNETWORK_ARG.AddArgument(subnetwork_group)
 
     router_flags.AddInterfaceArgs(parser)
 
+  @classmethod
+  def Args(cls, parser):
+    cls._Args(parser)
+
   def _GetGetRequest(self, client, router_ref):
     return (client.apitools_client.routers, 'Get',
             client.messages.ComputeRoutersGetRequest(
@@ -78,18 +92,21 @@ class AddInterface(base.UpdateCommand):
     mask = None
     interface_name = args.interface_name
 
+    if args.ip_address is not None:
+      if args.subnetwork is None and args.mask_length is not None:
+        mask = '{0}/{1}'.format(args.ip_address, args.mask_length)
+      elif args.subnetwork is None:
+        raise parser_errors.ArgumentException(
+            '--mask-length must be set if --ip-address is set')
+      elif args.mask_length is not None:
+        raise parser_errors.ArgumentException(
+            '--mask-length cannot be set if --subnetwork is set')
+
     if args.mask_length is not None:
       if args.mask_length < 0 or args.mask_length > 31:
         raise parser_errors.ArgumentException(
             '--mask-length must be a non-negative integer less than 32')
 
-    if args.ip_address is not None:
-      if args.mask_length is not None:
-        mask = '{0}/{1}'.format(args.ip_address, args.mask_length)
-      else:
-        raise parser_errors.ArgumentException(
-            '--mask-length must be set if --ip-address is set')
-
     if not args.vpn_tunnel_region:
       args.vpn_tunnel_region = replacement.region
     vpn_ref = None
@@ -106,12 +123,23 @@ class AddInterface(base.UpdateCommand):
       attachment_ref = self.INTERCONNECT_ATTACHMENT_ARG.ResolveAsResource(
           args, resources)
 
+    subnetwork_ref = None
+    private_ip_address = None
+    redundant_interface = None
+    if args.subnetwork is not None:
+      subnetwork_ref = self.SUBNETWORK_ARG.ResolveAsResource(args, resources)
+      private_ip_address = args.ip_address
+      redundant_interface = args.redundant_interface
+
     interface = client.messages.RouterInterface(
         name=interface_name,
         linkedVpnTunnel=(vpn_ref.SelfLink() if vpn_ref else None),
         linkedInterconnectAttachment=(attachment_ref.SelfLink()
                                       if attachment_ref else None),
-        ipRange=mask)
+        subnetwork=(subnetwork_ref.SelfLink() if subnetwork_ref else None),
+        ipRange=mask,
+        privateIpAddress=private_ip_address,
+        redundantInterface=redundant_interface)
 
     replacement.interfaces.append(interface)
 
