@@ -239,7 +239,7 @@ class Deploy(base.Command):
         )
         if execute_now:
           execution = operations.RunJob(
-              job_ref, args, tracker, self.ReleaseTrack()
+              job_ref, tracker, args.wait, args.async_, self.ReleaseTrack()
           )
 
       if args.async_ and not execute_now:
